package jdk.internal.org.objectweb.asm.tree;

import java.util.ArrayList;
import java.util.Map;
import jdk.internal.org.objectweb.asm.MethodVisitor;
import java.util.Arrays;
import java.util.List;

public class FrameNode extends AbstractInsnNode
{
    public int type;
    public List<Object> local;
    public List<Object> stack;
    
    private FrameNode() {
        super(-1);
    }
    
    public FrameNode(int type, int n, Object[] array, int n2, Object[] array2) {
        super(-1);
        switch (this.type = type) {
            case -1:
            case 0: {
                this.local = asList(n, array);
                this.stack = asList(n2, array2);
                break;
            }
            case 1: {
                this.local = asList(n, array);
                break;
            }
            case 2: {
                this.local = Arrays.asList(new Object[n]);
                break;
            }
            case 3: {
                break;
            }
            case 4: {
                this.stack = asList(1, array2);
                break;
            }
        }
    }
    
    @Override
    public int getType() {
        return 14;
    }
    
    @Override
    public void accept(MethodVisitor methodVisitor) {
        switch (this.type) {
            case -1:
            case 0: {
                methodVisitor.visitFrame(this.type, this.local.size(), asArray(this.local), this.stack.size(), asArray(this.stack));
                break;
            }
            case 1: {
                methodVisitor.visitFrame(this.type, this.local.size(), asArray(this.local), 0, (Object[])null);
                break;
            }
            case 2: {
                methodVisitor.visitFrame(this.type, this.local.size(), null, 0, (Object[])null);
                break;
            }
            case 3: {
                methodVisitor.visitFrame(this.type, 0, null, 0, (Object[])null);
                break;
            }
            case 4: {
                methodVisitor.visitFrame(this.type, 0, null, 1, asArray(this.stack));
                break;
            }
        }
    }
    
    @Override
    public AbstractInsnNode clone(Map<LabelNode, LabelNode> map) {
        FrameNode frameNode = new FrameNode();
        frameNode.type = this.type;
        if (this.local != null) {
            frameNode.local = new ArrayList();
            for (int i = 0; i < this.local.size(); ++i) {
                Object o = this.local.get(i);
                if ((o instanceof LabelNode)) {
                    o = map.get(o);
                }
                frameNode.local.add(o);
            }
        }
        if (this.stack != null) {
            frameNode.stack = new ArrayList();
            for (int j = 0; j < this.stack.size(); ++j) {
                Object o2 = this.stack.get(j);
                if ((o2 instanceof LabelNode)) {
                    o2 = map.get(o2);
                }
                frameNode.stack.add(o2);
            }
            return frameNode;
        }
        return frameNode;
    }
    
    private static List<Object> asList(int n, Object[] a) {
        return Arrays.asList(a).subList(0, n);
    }
    
    private static Object[] asArray(List<Object> list) {
        Object[] array = new Object[list.size()];
        Object o;
        for (int i = 0; i < array.length; array[i] = o, ++i) {
            o = list.get(i);
            if ((o instanceof LabelNode)) {
                o = ((LabelNode)o).getLabel();
            }
        }
        return array;
    }
}
